export type Scale = [number, number];
/**
 * Maps a numeric value from one scale (range) to another.
 *
 * This function performs a linear interpolation to convert a value from
 * its original scale to a new target scale, maintaining the relative
 * position of the value within both scales.
 *
 * @param {number} value - The number to be mapped.
 * @param {Scale} current - The current scale represented as a two-element array [min, max].
 * @param {Scale} target - The target scale represented as a two-element array [min, max].
 * @returns {number} The mapped value in the target scale.
 *
 * @example
 * // Map 5 from scale [0, 10] to [0, 100] -> returns 50
 * mapNumber(5, [0, 10], [0, 100]);
 */
export declare function mapNumber(value: number, current: Scale, target: Scale): number;
