/**
 * Converts a byte size into a human-readable string with units.
 *
 * @param {number|string} bytes - The size in bytes to format.
 * @param {number} [decimals=2] - Number of decimal places to include.
 * @returns {string} Formatted string representing the size (e.g., "1.23 MB").
 *
 * The function:
 * - Handles input as number or string convertible to number.
 * - Returns '0 Bytes' for falsy or zero values.
 * - Calculates the appropriate size unit based on powers of 1024.
 * - Limits decimal places based on the decimals parameter.
 */
export declare function formatBytes(bytes: number | string, decimals?: number): string;
/**
 * Converts a byte size into a tuple containing the numeric value and unit.
 *
 * @param {number|string} bytes - The size in bytes to format.
 * @param {number} [decimals=2] - Number of decimal places to include.
 * @returns {[number, string]} Tuple of the formatted number and its unit (e.g., [1.23, "MB"]).
 *
 * Useful for scenarios where numeric and unit parts need to be handled separately.
 */
export declare function formatBytesToParts(bytes: number | string, decimals?: number): [number, string];
