import { LabThumbnail } from './lab-thumbnail.type';
type LabCover = LabThumbnail;
/**
 * Represents a book in the lab ecosystem, including metadata, cover, and engagement metrics.
 */
export type LabBook = {
    /** Unique identifier for the book. */
    id: string;
    /** Hub identifier used in URLs. */
    _hid: string;
    /** Canonical URL to the book resource. */
    _url: string;
    /** Display title of the book. */
    title: string;
    /** Short summary or description of the book. */
    summary: string;
    /** Genre classification. */
    genre: string;
    /** Publisher of the book. */
    publisher: string;
    /** Unix timestamp representing release date. */
    releasedAt: number;
    /** Name of the book's author. */
    author: string;
    /** Array of topic tags for categorization. */
    topics: string[];
    /** Timestamp indicating creation or last update. */
    timestamp: number;
    /** Cover image with styling details. */
    cover: LabCover;
    /** ID of the user who submitted the book. */
    submitterId: string;
    /** Number of likes received. */
    likes: number;
    /** Count of users who added the book to their reading list. */
    readingListSize: number;
};
export {};
