import { LabContentAudio } from './lab-content-audio.type';
import { LabContentBanner } from './lab-content-banner.type';
import { LabContentCode } from './lab-content-code.type';
import { LabContentFiles } from './lab-content-file.type';
import { LabContentGridLR } from './lab-content-grid-lr.type';
import { LabContentGridLRR } from './lab-content-grid-lrr.type';
import { LabContentGridRLL } from './lab-content-grid-rll.type';
import { LabContentGrid } from './lab-content-grid.type';
import { LabContentImageText } from './lab-content-image-text.type';
import { LabContentImage } from './lab-content-image.type';
import { LabContentITLab, LabContentITLabPopulated } from './lab-content-itlab.type';
import { LabContentQuote } from './lab-content-quote.type';
import { LabContentRichtext } from './lab-content-richtext.type';
import { LabContentSlider } from './lab-content-slider.type';
import { LabContentVideo } from './lab-content-video.type';
/**
 * List of supported content block types for rich modular content layouts.
 */
export declare const LabContentTypes: readonly ["AUDIO", "CODE", "GRID", "GRID_LR", "GRID_LRR", "GRID_RLL", "IMAGE", "IMAGE_TEXT", "QUOTE", "RICHTEXT", "SLIDER", "VIDEO", "ITLAB", "BANNER", "FILES"];
/**
 * Union type representing all valid content type identifiers.
 */
export type LabContentType = (typeof LabContentTypes)[number];
/**
 * A flexible content block that may represent one of many supported structures.
 */
export type LabContentElement = {
    /** Type of content block. */
    type: LabContentType;
    /** Optional short description or caption for the block. */
    description?: string;
    /** Content-specific data structures, one per block type. */
    audio?: LabContentAudio;
    code?: LabContentCode;
    grid?: LabContentGrid;
    gridLR?: LabContentGridLR;
    gridLRR?: LabContentGridLRR;
    gridRLL?: LabContentGridRLL;
    image?: LabContentImage;
    imageText?: LabContentImageText;
    quote?: LabContentQuote;
    richtext?: LabContentRichtext | string;
    slider?: LabContentSlider;
    video?: LabContentVideo;
    itlab?: LabContentITLab;
    banner?: LabContentBanner;
    files?: LabContentFiles;
};
/**
 * A content element with IT Lab resources fully populated.
 */
export type LabContentElementPopulated = LabContentElement & {
    itlab?: LabContentITLabPopulated;
};
/**
 * A list of content elements composing a page or article.
 */
export type LabContent = LabContentElement[];
/**
 * A list of content elements with enriched IT Lab resources.
 */
export type LabContentPopulated = LabContentElementPopulated[];
