import { LabThumbnail } from './lab-thumbnail.type';
/** Event participation modes available. */
export declare const EVENT_MODES: readonly ["online", "onsite", "hybrid"];
/** Enum-like type defining allowed event participation modes. */
export type EventMode = (typeof EVENT_MODES)[number];
/** User-facing labels for each event mode. */
export declare const EventModeLabel: Record<EventMode, string>;
/**
 * Represents a scheduled lab event, including mode, timing, topics, and speaker data.
 */
export type LabEvent = {
    /** Unique event identifier. */
    id: string;
    /** Hub identifier used in URLs. */
    _hid: string;
    /** Canonical URL to the event resource. */
    _url: string;
    /** Unix timestamp of the event start time. */
    startAt: number;
    /** Unix timestamp of the event end time. */
    endAt: number;
    /** Title of the event. */
    title: string;
    /** Summary or abstract of the event. */
    summary: string;
    /** Indicates how the event is hosted: online, onsite, or hybrid. */
    mode: EventMode;
    /** Series or group the event belongs to. */
    series: string;
    /** Associated topics or themes. */
    topics: string[];
    /** List of speaker user IDs. */
    speakerIds: string[];
    /** Thumbnail image representing the event. */
    thumbnail: LabThumbnail;
    /** Downloadable resources (e.g., PDFs, slides). */
    downloads: {
        uri: string;
        filename: string;
    }[];
    /** Number of likes received. */
    likes: number;
    /** Number of registered or attended users. */
    attendees: number;
};
