import { LabThumbnail } from './lab-thumbnail.type';
/**
 * Represents a structured online course in the Hackschool program.
 */
export type LabHackschoolCourse = {
    /** Unique course identifier. */
    id: string;
    /** Hub identifier used in URLs. */
    _hid: string;
    /** Canonical URL to the course resource. */
    _url: string;
    /** Title of the course. */
    title: string;
    /** Brief summary describing the course content. */
    summary: string;
    /** Timestamp representing when the course was created or updated. */
    timestamp: number;
    /** Thumbnail image for the course. */
    thumbnail: LabThumbnail;
    /** Topical tags associated with the course. */
    topics: string[];
    /** Structured list of chapter groups within the course. */
    chapterGroups: {
        title: string;
        summary: string;
        chapters: {
            id: string;
            _hid: string;
            title: string;
            estimatedTime: number;
        }[];
    }[];
    /** Estimated total time (in minutes) to complete the course. */
    estimatedTime: number;
};
