/**
 * Represents a team member profile within the lab, including role, membership duration, and highlights.
 */
export type LabTeamMember = {
    /** Unique team member ID. */
    id: string;
    /** Hub identifier used in URLs. */
    _hid: string;
    /** Canonical URL to the member profile. */
    _url: string;
    /** Full name of the team member. */
    name: string;
    /** Role or title within the team. */
    role: string;
    /** Optional avatar image URL. */
    avatar?: string;
    /** Year the member joined the team. */
    member_since: number;
    /** Optional year the member left the team. */
    member_until?: number;
    /** List of yearly highlights or achievements. */
    highlights: {
        year: number;
        highlight: string;
    }[];
    /** List of Q&A entries to introduce the member. */
    qna: {
        q: string;
        a: string;
    }[];
    /** External links relevant to the member (e.g., social, portfolio). */
    links: {
        href: string;
        type: string;
    }[];
    /** Whether the team member is currently active. */
    active: boolean;
};
