/**
 * Represents a complete edition of the Tech Radar, including categorized blips and metadata.
 */
export type LabTechRadarEdition = {
    /** Unique edition ID. */
    id: string;
    /** Hub identifier used in URLs. */
    _hid: string;
    /** Canonical URL to the edition resource. */
    _url: string;
    /** Timestamp indicating when this edition was published. */
    timestamp: number;
    /** Blip IDs categorized under 'examine'. */
    examine: string[];
    /** Blip IDs categorized under 'observe'. */
    observe: string[];
    /** Blip IDs categorized under 'pilot'. */
    pilot: string[];
    /** Blip IDs categorized under 'utilize'. */
    utilize: string[];
    /** Tech Scout IDs contributing to the edition. */
    techScoutIds: string[];
    /**
     * Record of blip groupings by adoption level and tech type.
     * Structure: { examine: { tools: [], infrastructure: [], ... }, ... }
     */
    blips: Record<'examine' | 'observe' | 'pilot' | 'utilize', Partial<Record<'infrastructure' | 'tools' | 'techniques' | 'frameworks', {
        id: string;
        status: string;
    }[]>>>;
    /** Total number of blips in the edition. */
    total: number;
    /** Number of likes received. */
    likes: number;
    /** Title or theme of the radar edition. */
    title: string;
};
