/**
 * Converts arbitrary text into a standardized URL-friendly hub ID.
 *
 * @param {string} text - The input text to encode.
 * @returns {string} A sanitized, lowercase string suitable for use as a URL identifier.
 *
 * The function:
 * - Trims whitespace and lowercases the input.
 * - Replaces sequences of invalid characters with a single space.
 * - Collapses multiple hyphens into spaces.
 * - Trims and replaces whitespace sequences with hyphens.
 */
export declare function toHubId(text: string): string;
/**
 * Checks whether a given value is a valid Hub ID.
 *
 * A valid Hub ID:
 * - Is a non-empty string
 * - Contains only allowed characters (defined by `hubIdCharRegex`)
 * - Is not composed entirely of hyphens
 * - Does not start or end with a hyphen
 *
 * This validation ensures IDs are well-formed for use in URLs, database keys, etc.
 *
 * @param {unknown} value - The value to validate as a Hub ID.
 * @returns {boolean} `true` if the value is a valid Hub ID, otherwise `false`.
 */
export declare function isHubId(value: unknown): boolean;
