/**
 * Shortens a string to fit within a specified maximum length by
 * preserving the start and end parts, and inserting a delimiter in between.
 *
 * @param {string} value - The original string to shrink.
 * @param {number} [maxLength=20] - The maximum allowed length of the result string.
 * @param {string} [delimiter='…'] - The string to insert between the start and end parts when shrinking.
 * @returns {string} The possibly shortened string, with the delimiter separating
 *   the beginning and end if the original exceeds maxLength.
 *
 * This function is useful for displaying long strings (like file paths or IDs)
 * in a compact form without losing start/end context.
 */
export declare function shrinkString(value: string, maxLength?: number, delimiter?: string): string;
